# Tuniq 

Implementation of tuniq.unique() for list types.

## ⚡ Usage

```python
import tuniq

l = [1,3,4,5,8,4,6,2,7,2,5,3]
u = tuniq.unique(l)
print(u)
## should give [1,3,4,5,8,6,2,7]
```

## 🔧 Building

```shell
uv build
```

## 🤝 Collaborate with My Project

Please refer to the [collaboration guidelines](./COLLABORATION.md) for details.
